@@ -4,7 +4,7 @@ use 5.8.1;
 use strict;
 use File::Spec;
 use Carp;
-our $VERSION = v0.12.2;
+our $VERSION = v0.12.3;
 
 BEGIN {
     # XXX Use DateTime for release date?
@@ -140,13 +140,10 @@ sub path_for_html_doc {
     return unless $self->{docs} && $self->{docs}{$path};
 
     my $tmpl = $self->{_pgxn}->_uri_templates->{htmldoc} or return;
-    # XXX Nasty hack until we get + operator in URI Template v4.
-    local $URI::Escape::escapes{'/'} = '/';
     $tmpl->process(
-        dist       => lc $self->name,
-        version    => lc $self->version,
-        docpath    => $path,
-        '+docpath' => $path, # XXX Part of above-mentioned hack.
+        dist    => lc $self->name,
+        version => lc $self->version,
+        docpath => $path,
     );
 }
 
